#!/bin/sh
# Sets up a network interface for GigE Vision

if [ "$#" -lt 5 ]
then
    echo ""
    echo "Configure Network Interface for GigE Vision"
    echo ""
    echo "Input parameters:"
    echo "    <NIC>"
    echo "    <Total Receive Memory (bytes)>"
    echo "    <Interrupt Coalescing Setting (rx-usecs)>"
    echo "    <Camera IP>"
    echo "    <Host IP>"
    echo ""
    echo "Example: sh niimaqdx_configurenic.sh eth1 10000000 350 10.0.44.27 10.0.44.20"
    echo ""
else

    var_NIC=$1
    var_ReceiveMemory=$2
    var_Rxusecs=$3
    var_CameraIP=$4
    var_HostIP=$5

    # Increase the size of the packet receive buffer
    sysctl -w net.core.rmem_max=$var_ReceiveMemory

    # Change the interrupt coalescing setting (on all platforms except for ARM)
    if [ -z `uname -m | grep arm` ]
    then
        ethtool -C $var_NIC rx-usecs $var_Rxusecs
    fi

    # Add a route from the host to the camera
    # This should fix issues involving link-local routing with multiple network interfaces
    route add -net $var_CameraIP netmask 255.255.255.255 dev $var_NIC

fi